# Section58SummaryResponse

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**date_created** | **datetime** |  | 
**section_58_reference_number** | **str** |  | 
**street** | **str** |  | 
**town** | **str** |  | [optional] 
**area** | **str** |  | [optional] 
**section_58_status** | [**Section58StatusResponse**](Section58StatusResponse.md) |  | 
**section_58_status_string** | **str** |  | 
**start_date** | **datetime** |  | 
**end_date** | **datetime** |  | 
**restriction_duration** | [**Section58DurationResponse**](Section58DurationResponse.md) |  | 
**restriction_duration_string** | **str** |  | 
**usrn** | **float** |  | 
**ha_organisation_name** | **str** |  | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

